@@ -1,13 +1,27 @@
 package Devel::Examine::Subs::Sub;
-
 use strict;
 use warnings;
 
 use Data::Dumper;
 
-our $VERSION = '1.32';
+our $VERSION = '1.33';
+
+BEGIN {
+
+    # we need to do some trickery for DTS due to a circular install
+
+    eval {
+        require Devel::Trace::Subs;
+        import Devel::Trace::Subs qw(trace);
+    };
+
+    if ($@){
+        *trace = sub {};
+    }
+};
 
 sub new {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $class = shift;
     my $data = shift;
@@ -21,22 +35,27 @@ sub new {
     return $self;
 }
 sub name {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
     my $self = shift;
     return $self->{data}{name};
 }
 sub start {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
     my $self = shift;
     return $self->{data}{start};
 }
 sub end {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
     my $self = shift;
     return $self->{data}{end};
 }
 sub line_count {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
     my $self = shift;
     return $self->{data}{num_lines};
 }
 sub lines {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
 
@@ -55,6 +74,7 @@ sub lines {
     return \@line_linenum;
 }
 sub code {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
 
